

import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Calendar;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

@Entity
public class Link extends Entry {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private static final int SUSPENSION_THRESHOLD = 5;
	
	public static enum Status {	PENDING, WARNING, SUSPENDED, ACTIVE	}
	private String url;
	private Set<String> keywords = new HashSet<String>();
	private String contactEmail;
	@Temporal(TemporalType.DATE) private Calendar entryDate;
	@Temporal(TemporalType.DATE) private Calendar expirationDate;
	@Temporal(TemporalType.DATE) private Calendar refreshDate;
	@Enumerated(EnumType.STRING) private Status status;
	private int failureCount;
	private long clickCount;
	
	/**
	 * @return the url
	 */
	public String getUrl() {
		return url;
	}

	/**
	 * @param url the url to set
	 */
	public void setUrl(String url) {
		this.url = url;
	}

	/**
	 * @return the keywords
	 */
	public Set<String> getKeywords() {
		return keywords;
	}

	/**
	 * @param keywords the keywords to set
	 */
	public void setKeywords(Set<String> keywords) {
		this.keywords = keywords;
	}

	/**
	 * @return the contactEmail
	 */
	public String getContactEmail() {
		return contactEmail;
	}

	/**
	 * @param contactEmail the contactEmail to set
	 */
	public void setContactEmail(String contactEmail) {
		this.contactEmail = contactEmail;
	}

	/**
	 * @return the entryDate
	 */
	public Calendar getEntryDate() {
		return entryDate;
	}

	/**
	 * @param entryDate the entryDate to set
	 */
	public void setEntryDate(Calendar entryDate) {
		this.entryDate = entryDate;
	}

	/**
	 * @return the expirationDate
	 */
	public Calendar getExpirationDate() {
		return expirationDate;
	}

	/**
	 * @param expirationDate the expirationDate to set
	 */
	public void setExpirationDate(Calendar expirationDate) {
		this.expirationDate = expirationDate;
	}

	/**
	 * @return the refreshDate
	 */
	public Calendar getRefreshDate() {
		return refreshDate;
	}

	/**
	 * @param refreshDate the refreshDate to set
	 */
	public void setRefreshDate(Calendar refreshDate) {
		this.refreshDate = refreshDate;
	}

	/**
	 * @return the status
	 */
	public Status getStatus() {
		return status;
	}

	/**
	 * @param status the status to set
	 */
	public void setStatus(Status status) {
		this.status = status;
	}

	/**
	 * @return the clickCount
	 */
	public long getClickCount() {
		return clickCount;
	}

	/**
	 * @param clickCount the clickCount to set
	 */
	public void setClickCount(long clickCount) {
		this.clickCount = clickCount;
	}
	
	private int getFailureCount() {
		return failureCount;
	}

	private void setFailureCount(int failureCount) {
		this.failureCount = failureCount;
	}

	public void registerClick() {
		setClickCount(getClickCount()+1);
	}
	
	@Override
	public boolean equals(Object obj) {
		if (obj == null || !(obj instanceof Link)) {
			return false;
		}
		Link that = (Link) obj;
		return this.url.equals(that.url);
	}

	@Override
	public int hashCode() {
		return this.url.hashCode();
	}

	@Override
	public String toString() {
		return super.toString() + "\t" + this.url;
	}

	
}
